@@ -14,9 +14,9 @@ class N2PComponent:
     '''Class which contains the information associated to a component of a N2PResult instance.
 
     Attributes:
-        Name: str
-        Sections: list[N2PSection]
-        IsTransformable: bool
+        Name: str.
+        Sections: list[N2PSection].
+        IsTransformable: bool.
     '''
 
     # Constructor de N2PComponent
@@ -55,9 +55,9 @@ class N2PComponent:
         """Property that keeps if the component of a result is transformable in other coordinate system.
         """
         # No se guarda como atributo privado durante la instanciacion de un objeto porque algunas variables
-        # aun no se han construido. Por eso el metodo de la propiedad es la que busca los ragumentos y llama
+        # aun no se han construido. Por eso el metodo de la propiedad es la que busca los argumentos y llama
         # al metodo dentro de Vizzer classes.
-        solver = self.__result_father__.__loadCase_father__.__modelFather__._N2PModelContent__vzmodel.Solver
+        solver = self.__result_father__.__loadCase_father__.__solver__
         result = self.__result_father__.Name
         component = self.Name
         return bool(N2TensorTransformation.IsResultSupported(solver, result, component))
@@ -81,21 +81,21 @@ class N2PComponent:
 
         Args:
         
-            sections: list[str] | list[N2PSection] -> Sections which operations are done.
+            sections: list[str] | list[N2PSection] -> Optional. Sections which operations are done.
                 None (Default) = All Sections
 
-            aveSections: int -> Operation Among Sections.
+            aveSections: int -> Optional. Operation Among Sections.
                 -1 : Maximum (Default),
                 -2 : Minimum,
                 -3 : Average,
                 -4 : Extreme,
                 -6 : Difference.
 
-            cornerData: bool -> flag to get results in element nodal.
+            cornerData: bool -> Optional. Flag to get results in element nodal.
                 True : Results in Element-Nodal,
                 False : Results in centroid (Default).
 
-            aveNodes: int -> Operation among nodes when cornerData is selected.
+            aveNodes: int -> Optional. Operation among nodes when cornerData is selected.
                 0 : None,
                 -1 : Maximum (Default),
                 -2 : Minimum,
@@ -103,23 +103,23 @@ class N2PComponent:
                 -5 : Average with variation parameter,
                 -6 : Difference.
 
-            variation: int -> Integer between 0 & 100 to select.
+            variation: int -> Optional. Integer between 0 & 100 to select.
                 0 : No average between nodes,
                 100 : Total average between nodes (Default).
 
-            realPolar: int -> data type when complex result.
+            realPolar: int -> Optional. Data type when complex result.
                 1 : Real / Imaginary,
                 2 : Magnitude / Phase.
 
-            coordsys: int -> Coordinate System where the result_array will be represented.
+            coordsys: int -> Optional. Coordinate System where the result_array will be represented.
                 0   : Global,
                 -1  : Material Coordinate System,
                 -10 : User defined,
                 >0  : Solver ID of the Predefined Coordinate System.
 
-            v1: tuple
+            v1: tuple -> Optional.
 
-            v2: tuple -> Directions vectors that generate the coordinate system axis:
+            v2: tuple -> Optional. Directions vectors that generate the coordinate system axis:
                 x=v1,
                 z=v1^v2,
                 y=z^x.
@@ -141,13 +141,7 @@ class N2PComponent:
 
         resultsParameters = self._create_n2paraminputresult(sections, aveSections, cornerData, aveNodes, variation,
                                                             realPolar, coordsys, v1, v2)
-
-        if self.__result_father__.__loadCase_father__.TypeLC == "DERIVED":
-            results = list(self.__result_father__.__loadCase_father__._N2PLoadCase__n2loadcase.CalculateLastArray(
-                           resultsParameters, 0))
-
-        else:
-            results = list(
+        results = list(
             self.__result_father__.__loadCase_father__.__modelFather__._N2PModelContent__vzmodel.CalculateArrayLastResult(
                 resultsParameters, 0))
 
@@ -169,23 +163,21 @@ class N2PComponent:
         """ Returns a tuple with the numpy array of floats with the result array asked and a str with the position of
         the results
 
-        Args:
-
-            sections: list[str] | list[N2PSection] -> Sections which operations are done.
+            sections: list[str] | list[N2PSection] -> Optional. Sections which operations are done.
                 None (Default) = All Sections
 
-            aveSections: int -> Operation Among Sections.
+            aveSections: int -> Optional. Operation Among Sections.
                 -1 : Maximum (Default),
                 -2 : Minimum,
                 -3 : Average,
                 -4 : Extreme,
                 -6 : Difference.
 
-            cornerData: bool -> flag to get results in element nodal.
+            cornerData: bool -> Optional. Flag to get results in element nodal.
                 True : Results in Element-Nodal,
                 False : Results in centroid (Default).
 
-            aveNodes: int -> Operation among nodes when cornerData is selected.
+            aveNodes: int -> Optional. Operation among nodes when cornerData is selected.
                 0 : None,
                 -1 : Maximum (Default),
                 -2 : Minimum,
@@ -193,23 +185,23 @@ class N2PComponent:
                 -5 : Average with variation parameter,
                 -6 : Difference.
 
-            variation: int -> Integer between 0 & 100 to select.
+            variation: int -> Optional. Integer between 0 & 100 to select.
                 0 : No average between nodes,
                 100 : Total average between nodes (Default).
 
-            realPolar: int -> data type when complex result.
+            realPolar: int -> Optional. Data type when complex result.
                 1 : Real / Imaginary,
                 2 : Magnitude / Phase.
 
-            coordsys: int -> Coordinate System where the result_array will be represented.
+            coordsys: int -> Optional. Coordinate System where the result_array will be represented.
                 0   : Global,
                 -1  : Material Coordinate System,
                 -10 : User defined,
                 >0  : Solver ID of the Predefined Coordinate System.
 
-            v1: tuple|ndarray
+            v1: tuple -> Optional.
 
-            v2: tuple|ndarray -> Directions vectors that generate the coordinate system axis:
+            v2: tuple -> Optional. Directions vectors that generate the coordinate system axis:
                 x=v1,
                 z=v1^v2,
                 y=z^x.
@@ -380,7 +372,8 @@ class N2PComponent:
         cs_dict = self.__result_father__.__loadCase_father__.__modelFather__._N2PModelContent__vzmodel.CalculateArrayLastResult(
                 formula, resultsParameters, 0)
 
-        py_dict = {(int(key.split(":")[0].split("LC")[1]), int(key.split(":")[1][2:])): np.array(value, np.float64)
+        py_dict = {(int(key.split(":")[0].replace("DoF_LCD", "-").replace("DoF_LC", "")),
+                    int(key.split(":")[1][2:])): np.array(value, np.float64)
                    for key, value in dict(cs_dict[0]).items()}
 
         return py_dict
