@@ -66,6 +66,7 @@ class N2PModelContent:
         self.__elements_coord_sys = None
         self.__material_coord_sys = None
         self.__cells_list = None  # Lista con N2PElement y N2PConnector
+        self.__connectivity_dict = {}
 
         if (solver is None) and (solver != "InputFileNastran") and (solver != "Binary"):
             t1 = time.time()
@@ -255,7 +256,8 @@ class N2PModelContent:
         del listadeconectores
         # OJO. EN NASTRAN SE PUEDEN TENER VARIOS MPC CON EL MISMO ID, POR TANTO SE GUARDARAN COMO UNA LISTA DE
         # N2PConnectors
-        self.__cells_list += list(self.__connector_dict.values())
+        self.__cells_list += [conn for conn_list in self.__connector_dict.values()
+                              for conn in (conn_list if isinstance(conn_list, list) else [conn_list])]
         t2 = time.time()
         N2PLog.Debug.D100("N2PConnector Dictionary", t2-t1)
         # --------------------------------------------------------------------------------------------------------------
@@ -508,7 +510,7 @@ class N2PModelContent:
                 return elements
 
             if ids != 0 and isinstance(ids, int):
-                if self.Solver == "Nastran" or self.Solver == "Optistruct" or self.Solver == "Ansys":
+                if self.Solver == "Nastran" or self.Solver == "Optistruct" or self.Solver == "Ansys" or self.Solver == "InputFileNastran":
                     if len(self.__partIDtoStr) > 1:
                         N2PLog.Error.E223()
                         elements = -2
@@ -548,7 +550,7 @@ class N2PModelContent:
 
                 if isinstance(ids[0], int):
                     for id in ids:
-                        if self.Solver == "Nastran" or self.Solver == "Optistruct" or self.Solver == "Ansys":
+                        if self.Solver == "Nastran" or self.Solver == "Optistruct" or self.Solver == "Ansys" or self.Solver == "InputFileNastran":
                             if len(self.__partIDtoStr) > 1:
                                 N2PLog.Error.E223()
                                 elemento = -2
@@ -569,7 +571,7 @@ class N2PModelContent:
         except:
             elements = -1
             N2PLog.Error.E205(ids)
-            return elements   
+            return elements
     # ------------------------------------------------------------------------------------------------------------------
 
     # Metodo general para nodos ----------------------------------------------------------------------------------------
@@ -593,7 +595,7 @@ class N2PModelContent:
                 return nodes
 
             if ids != 0 and isinstance(ids, int):
-                if self.Solver == "Nastran" or self.Solver == "Optistruct" or self.Solver == "Ansys":
+                if self.Solver == "Nastran" or self.Solver == "Optistruct" or self.Solver == "Ansys" or self.Solver == "InputFileNastran":
                     if len(self.__partIDtoStr) > 1:
                         N2PLog.Error.E224()
                         nodes = -2
@@ -635,7 +637,7 @@ class N2PModelContent:
 
                 if isinstance(ids[0], int):
                     for id in ids:
-                        if self.Solver == "Nastran" or self.Solver == "Optistruct" or self.Solver == "Ansys":
+                        if self.Solver == "Nastran" or self.Solver == "Optistruct" or self.Solver == "Ansys" or self.Solver == "InputFileNastran":
                             if len(self.__partIDtoStr) > 1:
                                 N2PLog.Error.E224()
                                 nodo = -2
@@ -656,7 +658,7 @@ class N2PModelContent:
         except:
             nodes = -1
             N2PLog.Error.E205(ids)
-            return nodes   
+            return nodes
     # ------------------------------------------------------------------------------------------------------------------
 
     # Metodo general para conectores -----------------------------------------------------------------------------------
@@ -680,7 +682,7 @@ class N2PModelContent:
                 return connectors
 
             if ids != 0 and isinstance(ids, int):
-                if self.Solver == "Nastran" or self.Solver == "Optistruct" or self.Solver == "Ansys":
+                if self.Solver == "Nastran" or self.Solver == "Optistruct" or self.Solver == "Ansys" or self.Solver == "InputFileNastran":
                     if len(self.__partIDtoStr) > 1:
                         N2PLog.Error.E225()
                         connectors = -2
@@ -721,7 +723,7 @@ class N2PModelContent:
 
                 if isinstance(ids[0], int):
                     for id in ids:
-                        if self.Solver == "Nastran" or self.Solver == "Optistruct" or self.Solver == "Ansys":
+                        if self.Solver == "Nastran" or self.Solver == "Optistruct" or self.Solver == "Ansys" or self.Solver == "InputFileNastran":
                             if len(self.__partIDtoStr) > 1:
                                 N2PLog.Error.E225()
                                 conector = -2
@@ -885,6 +887,7 @@ class N2PModelContent:
                                            lc.Name,
                                            lc.Results,
                                            lc.SolutionType,
+                                           lc.Solver,
                                            self,
                                            lc) for lc in lcs]
 
